@@ -1,3 +1,5 @@
+use std::rc::Rc;
+
 use nNye_solana_communication_layer::ISolana;
 use super::content::Content;
 use super::enums::MediaType;
@@ -10,14 +12,14 @@ pub struct ContentNotification {
     /// The id of the content that was posted.
     content_id: u32,
 
-    solana: Box<dyn ISolana>
+    solana: Rc<dyn ISolana>
 }
 
 impl ContentNotification {
 
     pub fn new(pub_key: String, 
                content_id: u32, 
-               solana: Box<dyn ISolana>) -> Self {
+               solana: Rc<dyn ISolana>) -> Self {
         ContentNotification{ pub_key: pub_key, content_id: content_id, solana: solana }
     }
 
